ImageReadMapping

Struct ImageReadMapping 

pub struct ImageReadMapping<'buffer> { /* private fields */ }
A wrapper around a slice of bytes representing an image.

An ImageReadMapping may only be created via RowPaddedBuffer::read().

Implementations

Source

impl<'buffer> ImageReadMapping<'buffer>

pub unsafe fn as_image<P>(&self) -> SubImage<ImageHolder<'_, P>>
where P: Pixel + PixelWithColorType + 'static,

View as an image::SubImage.

Unsafe: P::TEXTURE_FORMAT MUST match the texture format / image type used to create the wrapped RowPaddedBuffer! If this is not the case, may result in undefined behavior!