pub struct ImageReadMapping<'buffer> { /* private fields */ }Expand description
A wrapper around a slice of bytes representing an image.
An ImageReadMapping may only be created via RowPaddedBuffer::read().
Implementations
Sourceimpl<'buffer> ImageReadMapping<'buffer>
impl<'buffer> ImageReadMapping<'buffer>
Sourcepub unsafe fn as_image<P>(&self) -> SubImage<ImageHolder<'_, P>>where
P: Pixel + 'static,
pub unsafe fn as_image<P>(&self) -> SubImage<ImageHolder<'_, P>>where
P: Pixel + 'static,
View as an image::SubImage.
Unsafe: P::TEXTURE_FORMAT MUST match the texture format / image type used to create the
wrapped RowPaddedBuffer! If this is not the case, may result in undefined behavior!